translate.storage.wordfast.WordfastTime

Package translate :: Package storage :: Module wordfast :: Class WordfastTime |
[hide private]
[frames] | no frames]

# Class WordfastTime

source code

Manages time stamps in the Wordfast format of YYYYMMDD~hhmmss

Instance Methods | [hide private]
__init__(self, newtime=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
get_timestring(self) Get the time in the Wordfast time format | source code
set_timestring(self, timestring) Set the time_sturct object using a Wordfast time formated string | source code
get_time(self) Get the time_struct object | source code
set_time(self, newtime) Set the time_struct object | source code
__str__(self) str(x) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
| timestring = `property(get_timestring, set_timestring)`
| time = `property(get_time, set_time)`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, newtime=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### set_timestring(self, timestring) | source code
Set the time_sturct object using a Wordfast time formated string Parameters: `timestring` (String) - A Wordfast time string (YYYMMDD~hhmmss)

### set_time(self, newtime) | source code
Set the time_struct object Parameters: `newtime` (time.time_struct) - a new time object

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)